@@ -28,6 +28,7 @@ void output_init(output_t *output) {
 	output->recp = NULL;
 	output->memp = NULL;
 	output->sortfield = 0;
+	pthread_mutex_init(&output->write_lock, NULL);
 
 }
 
@@ -177,7 +178,7 @@ int output_output_rows(output_t *output) {
 			output->outputflows++;
 			output_row(output, output->recp);
 
-			/* if the limit of output files is set */
+			/* if the limit of output rows is set */
 			if (output->limit > 0 && output->outputflows >= output->limit) {
 				break;
 			}
